@@ -1,17 +1,16 @@
 import click
-import sys
 import getpass
 import pyhectiqlab
 import pyhectiqlab.ops as ops
 from pyhectiqlab.auth import AuthProvider
-from pyhectiqlab.artifacts import SharedArtifactsManager
 from pyhectiqlab.mlmodels import download_mlmodel as ops_download_mlmodel
 from pyhectiqlab.datasets import download_dataset as ops_download_dataset
+from pyhectiqlab.apps import download_app as ops_download_app
 import socket
 
 @click.group()
 def cli():
-    """Just a group."""
+    """The official hectiqlab command line client"""
     pass
 
 @cli.command()
@@ -31,7 +30,7 @@ def add_profile():
 		click.echo(f'Added profile [{username}] in {auth.tokens_path}')
 		try:
 			api_name = socket.gethostname()
-			res = ops.update_secret_api_token_name(api_key_uuid, name=api_name, token=auth.secret_api_key)
+			ops.update_secret_api_token_name(api_key_uuid, name=api_name, token=auth.secret_api_key)
 			click.echo(f'Set the API-key name to {api_name}.')
 		except:
 			return
@@ -41,36 +40,22 @@ def add_profile():
 @cli.command()
 def version():
 	click.echo(pyhectiqlab.__version__)
-	
-@cli.command()
-def projects():	
-	manager = SharedArtifactsManager()
-	manager.list_projects()
 
 @cli.command()
-@click.option('-p', '--project_id', help='id of the project', required=True)
-def artifacts(project_id):
-	manager = SharedArtifactsManager()
-	manager.select_artifact(project_id)
+def profiles():
+	auth = AuthProvider()
+	profiles = list(auth.profiles.keys())
+	click.echo(profiles)
 
 @cli.command()
-@click.option('-p', '--project_id', help='id of the project', required=True)
-@click.option('-f', '--filepath', help='Name of the shared artifact', required=True)
-def post_artifact(project_id, filepath):
-	manager = SharedArtifactsManager()
-	click.echo('Pushing artifacts.')
-	manager.push_artifact(filepath, project_id)
-	click.echo('Artifact pushed')
-
-@cli.command()
-@click.option('-p', '--project_id', help='id of the project', required=False)
+@click.option('-p', '--project', prompt="Project", help='Path of the project (e.g. `hectiqai/project`)', required=True)
 @click.option('-n', '--name', prompt='MLModel name', help='Name of the mlmodel', required=True)
 @click.option('-v', '--version', help='Version of the mlmodel. If not specified, will download the latest release', required=False)
-@click.option('-s', '--save_path', prompt='Save path', help='Save path', required=True)
+@click.option('-s', '--save_path', help='Save path [./]', default="./", required=False)
 @click.option('-o', '--overwrite', is_flag=True)
-def download_mlmodel(project_id, name, version, save_path, overwrite):
+def download_mlmodel(project, name, version, save_path, overwrite):
 	dir_path = ops_download_mlmodel(mlmodel_name=name, 
-						project_id=project_id, 
+						project_path=project, 
 						version=version, 
 						save_path=save_path, 
 						overwrite=overwrite)
@@ -78,16 +63,31 @@ def download_mlmodel(project_id, name, version, save_path, overwrite):
 		click.echo(f'MLModel saved in {dir_path}')
 
 @cli.command()
-@click.option('-p', '--project_id', help='id of the project', required=False)
+@click.option('-p', '--project', prompt="Project", help='Path of the project (e.g. `hectiqai/project`)', required=True)
 @click.option('-n', '--name', prompt='Dataset name', help='Name of the dataset', required=True)
 @click.option('-v', '--version', help='Version of the dataset. If not specified, will download the latest release', required=False)
-@click.option('-s', '--save_path', prompt='Save path', help='Save path', required=True)
+@click.option('-s', '--save_path', help='Save path [./]', default="./", required=True)
 @click.option('-o', '--overwrite', is_flag=True)
-def download_dataset(project_id, name, version, save_path, overwrite):
+def download_dataset(project, name, version, save_path, overwrite):
 	dir_path = ops_download_dataset(dataset_name=name, 
-						project_id=project_id, 
+						project_path=project, 
 						version=version, 
 						save_path=save_path, 
 						overwrite=overwrite)
 	if dir_path is not None:
 		click.echo(f'Dataset saved in {dir_path}')
+
+@cli.command()
+@click.option('-p', '--project', prompt="Project", help='Path of the project (e.g. `hectiqai/project`)', required=True)
+@click.option('-n', '--name', prompt='App name', help='Name of the app', required=True)
+@click.option('-s', '--save_path', help='Save path [./]', default="./", required=True)
+@click.option('-o', '--overwrite', is_flag=True)
+@click.option('-r', '--raw', help='If set, the files are downloaded in save_path without directory', is_flag=True)
+def download_app(project, name, save_path, overwrite, raw):
+	dir_path = ops_download_app(app_name=name, 
+						project_path=project, 
+						save_path=save_path, 
+						overwrite=overwrite,
+						no_dir=raw)
+	if dir_path is not None:
+		click.echo(f'App saved in {dir_path}')
