@@ -4,6 +4,9 @@ from pyhectiqlab.timer import RepeatedTimer
 import numpy as np
 import time
 
+import logging
+logger = logging.getLogger('pyhectiqlab')
+
 class MetricsManager():
 
     def __init__(self, max_cache_timeout=10,  # Maximum number of seconds in the cache
@@ -13,7 +16,8 @@ class MetricsManager():
                     push_method=None):
         self.cache = defaultdict(list)
         self.cache_last_push = {}
-        self._max_cache_quantity = 1000
+        self.__max_cache_quantity_per_second = 200
+        self._warning_is_shown = False
         self.max_cache_length = max_cache_length
         self.min_cache_flush_delay  = min_cache_flush_delay
         self.push_method = push_method
@@ -52,13 +56,16 @@ class MetricsManager():
             self.push_data(key)
 
     def subsample(self, data):
-        if len(data)<=self._max_cache_quantity:
+        normalized_max = int(self.__max_cache_quantity_per_second*self.min_cache_flush_delay)
+        if len(data)<=normalized_max:
             return data
         else:
-            print(f"Your metrics rate ({len(data)} metrics/5 seconds) is exceeding the maximum rate ({self._max_cache_quantity}/5 seconds). Your metrics have been subsampled automatically.")
-            print("Consider reducing the number of metrics you push or settings an aggregation method with `run.set_metrics_aggr('mean')`.")
-            print("See documentation for details https://docs.hectiq.ai/objects/metrics/.")
-            indexes = np.arange(0, len(data), len(data)/self._max_cache_quantity).astype(int)
+            if self._warning_is_shown==False:
+                logger.warning(f"Your metrics rate ({len(data)//self.min_cache_flush_delay} metrics/second) is exceeding the maximum rate ({self.__max_cache_quantity_per_second}/second). Your metrics have been subsampled automatically.")
+                logger.warning("Consider reducing the number of metrics you push or setting an aggregation method with `run.set_metrics_aggr('mean')`.")
+                logger.warning("See the documentation for details https://docs.hectiq.ai/objects/metrics/.")
+                self._warning_is_shown = True
+            indexes = np.linspace(0, len(data)-1, normalized_max).astype(int)
             return np.array(data)[indexes].tolist()
 
     def push_data(self, key):
