@@ -40,7 +40,7 @@ class PaperContent():
     def hrule(self):
         self.text += '-------------------------------\n'
     
-    def update_run_paper(self, run: 'Run'):
+    def update_run_paper(self, run):
         run.set_paper(self.text)
 
     def __str__(self):
